package ru.ulstu.extractor.rule.controller;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.mvc.support.RedirectAttributes;
import ru.ulstu.extractor.rule.model.AddRuleForm;
import ru.ulstu.extractor.rule.repository.RuleRepository;
import ru.ulstu.extractor.rule.service.AntecedentValueService;
import ru.ulstu.extractor.rule.service.RuleService;
import ru.ulstu.extractor.ts.service.TimeSeriesService;
import springfox.documentation.annotations.ApiIgnore;

import static ru.ulstu.extractor.core.Route.*;

@Controller
@ApiIgnore
public class RuleController {
    private final RuleService ruleService;
    private final AntecedentValueService antecedentValueService;
    private final TimeSeriesService timeSeriesService;
    private final RuleRepository ruleRepository;

    public RuleController(RuleService ruleService,
                          AntecedentValueService antecedentValueService,
                          TimeSeriesService timeSeriesService, RuleRepository ruleRepository) {
        this.ruleService = ruleService;
        this.antecedentValueService = antecedentValueService;
        this.timeSeriesService = timeSeriesService;
        this.ruleRepository = ruleRepository;
    }

    @GetMapping(LIST_RULE)
    public String getList(Model model) {
        model.addAttribute("rules", ruleService.getList());
        return LIST_RULE;
    }

    @GetMapping(ADD_RULE)
    public String getAntecedent(Model model) {
        model.addAttribute("antecedentValues", antecedentValueService.getList());
        model.addAttribute("antecedents", timeSeriesService.getAllTimeSeriesTypes());
        model.addAttribute("addRuleForm", new AddRuleForm());
        return ADD_RULE;
    }

    @RequestMapping(value = ADD_RULE, method = RequestMethod.POST)
    public String addRule(@ModelAttribute AddRuleForm ruleForm, Model model, RedirectAttributes redirectAttributes) {
        ruleService.saveRule(ruleForm);
        return "redirect:/" + LIST_RULE;
    }

    @GetMapping(DELETE_RULE)
    public String deleteRule(Model model,
                             @RequestParam Integer id) {
        ruleRepository.deleteById(id);
        model.addAttribute("rule", ruleRepository.findAll());
        return "redirect:/" + LIST_RULE;
    }

//    @RequestMapping(value = FILTER_COMMITS, method = RequestMethod.GET)
//    public String editRule(Model model,
//                           @RequestParam Optional<Integer> firstAntecedentValueId,
//                           @RequestParam Optional<String > firstAntecedentId,
//                           @RequestParam Optional<Integer> secondAntecedentValueId,
//                           @RequestParam Optional<String> secondAntecedentId,
//                           @RequestParam Optional<String> consequent){
//        AddRuleForm addRuleForm = new AddRuleForm();
//        addRuleForm.setFirstAntecedentId(firstAntecedentValueId.);
//        addRuleForm.setFirstAntecedentValueId();
//        addRuleForm.setSecondAntecedentId();
//        addRuleForm.setSecondAntecedentValueId();
//        addRuleForm.setConsequent();
//    }
}
